@@ -996,6 +996,8 @@ QString BatchRenamer::findPartStrings(QString oldname, QString token)
             x++;
         }
 
+        oldname = unEscape(oldname);
+
         return oldname.mid(first.toInt() - 1, x);
     } else if (token.contains(';')) {
         pos = token.indexOf(';', 0);
@@ -1003,11 +1005,15 @@ QString BatchRenamer::findPartStrings(QString oldname, QString token)
         first = token.left(pos);
         second = token.mid(pos + 1, token.length());
 
+        oldname = unEscape(oldname);
+
         return oldname.mid(first.toInt() - 1, second.toInt());
     } else {
         bool ok = false;
         int number = token.toInt(&ok);
 
+        oldname = unEscape(oldname);
+
         if (ok && (number <= (signed int)oldname.length() && number > 0)) {
             return QString(oldname[ number - 1 ]);
         } else {
@@ -1061,7 +1067,10 @@ QString BatchRenamer::findLength(const QString &token, const QString &name)
             }
         }
 
-        return QString::number(name.length() - minus);
+        QString escaped = name;
+        escaped = doEscape(escaped);
+
+        return QString::number(escaped.length() - minus);
     }
 
     return QString();
@@ -1136,13 +1145,13 @@ void BatchRenamer::writeUndoScript(QTextStream *t)
          << "# KRename Undo Script" << endl << "#" << endl
          << "# KRename was written by:" << endl
          << "# Dominik Seichter <domseichter@web.de>" << endl
-         << "# http://krename.sourceforge.net" << endl << "#" << endl
+         << "# https://www.krename.net/" << endl << "#" << endl
          << "# Script generated by KRename Version: " << VERSION << endl << endl
          << "# This script must be started with the option --krename to work!" << endl;
 
     // write functions:
     (*t) << "echo \"KRename Undo Script\"" << endl
-         << "echo \"http://krename.sourceforge.net\"" << endl
+         << "echo \"https://www.krename.net/\"" << endl
          << "echo \"\"" << endl;
 
     (*t) << "if test --krename = $1 ; then" << endl
